@@ -11,9 +11,7 @@ use overload
     '""' => \&as_string,
     fallback => 1;
 
-$VERSION = '1.09';
-
-1;
+$VERSION = '1.10';
 
 sub new
 {
@@ -110,6 +108,7 @@ sub _ref_as_string
 {
     my $self = shift;
 
+    local $@;
     if ( ref $_[0] &&
          ! $self->{respect_overload} &&
          eval { overload::Overloaded($_[0]) }
@@ -301,7 +300,8 @@ sub as_string
 		$_ = "undef", next unless defined $_;
 
                 # hack!
-                $_ = $self->Devel::StackTrace::_ref_as_string($_);
+                $_ = $self->Devel::StackTrace::_ref_as_string($_)
+                    if ref $_;
 
 		s/'/\\'/g;
 
